@@ -515,10 +515,17 @@ def cmd2api_output_mhci(cmd_output):
                 field_name = key
             if field_name in unique_vals:
                 value_limits['unique_values'] = unique_vals[field_name]
+            # check lowercase version of the field name
+            elif field_name.lower() in unique_vals:
+                value_limits['unique_values'] = unique_vals[field_name.lower()]
 
             if field_name in field_ranges:
                 value_limits['min'] = float(field_ranges[field_name]['min'])
                 value_limits['max'] = float(field_ranges[field_name]['max'])
+            # check lowercase version of the field name
+            elif field_name.lower() in field_ranges:
+                value_limits['min'] = float(field_ranges[field_name.lower()]['min'])
+                value_limits['max'] = float(field_ranges[field_name.lower()]['max'])
             
             if value_limits:
                 f['value_limits'] = value_limits
