@@ -95,6 +95,15 @@ def aggregate_result_file(job_desc_file, output_dir, aggregate_output_dir, has_c
         # skip over non-prediction jobs
         if j['job_type'] != 'prediction':
             continue
+        # skip over jobs that have no expected outputs
+        if 'expected_outputs' not in j:
+            continue
+        if not j['expected_outputs']:
+            continue
+        # skip over jobs that have expected outputs that do not exist
+        if not all([os.path.exists(o) for o in j['expected_outputs']]):
+            warnings.add("The expected output files for job %s do not all exist. This job will be skipped." % j['job_id'])
+            continue
 
         # loop through the expected outputs of prediction jobs
         for o in j['expected_outputs']:
@@ -162,7 +171,10 @@ def aggregate_result_file(job_desc_file, output_dir, aggregate_output_dir, has_c
             for field in ['ic50', 'score', 'percentile',]:
                 if peptide_table.get(field, None) is not None:
                     peptide_table[field] = peptide_table[field].astype('float64')
-            join_cols = ['peptide', 'allele']
+            join_cols = ['peptide']
+            # if allele is in both tables, we need to join on it
+            if 'allele' in peptide_table and 'core.' + 'allele' in final_peptide_table:
+                join_cols.append('allele')
             left_join_cols = ['core.' + x for x in join_cols]
             right_join_cols = [m + '.' + x for x in join_cols]
             final_peptide_table = pd.merge(final_peptide_table, peptide_table.add_prefix(m + '.'),
@@ -202,7 +214,10 @@ def aggregate_result_file(job_desc_file, output_dir, aggregate_output_dir, has_c
             for field in ['score', ]:
                 if peptide_table.get(field, None) is not None:
                     peptide_table[field] = peptide_table[field].astype('float64')
-            join_cols = ['peptide', 'allele']
+            join_cols = ['peptide']
+            # if allele is in both tables, we need to join on it
+            if 'allele' in peptide_table and 'core.' + 'allele' in final_peptide_table:
+                join_cols.append('allele')
             left_join_cols = ['core.' + x for x in join_cols]
             right_join_cols = [m + '.' + x for x in join_cols]
             final_peptide_table = pd.merge(final_peptide_table, peptide_table.add_prefix(m + '.'),
