@@ -260,12 +260,8 @@ class MHCFlurryPredictor():
                     sys.stderr.write("Sequence: '%s' contains an invalid character: '%c' at position %d.\n" % (sequences, amino_acid, sequences.find(amino_acid)))
                     exit(1)
 
-        allele_list = input_allele.split(",")
-        allele_list = [allele.strip().replace('*','').replace(':','') for allele in allele_list]
-
-        from mhcflurry_predictor import mhcflurry_predict
-
-        result = mhcflurry_predict(peptide_list, allele_list)
+        from mhcflurry_predicter import predict as mhcflurry_predict
+        result = mhcflurry_predict(input_allele=input_allele,  fname=fname)
 
         # print_result_in_tsv
         if not result:
