@@ -93,7 +93,6 @@ def split_peptides_with_diff_length(input_sequence_text, peptide_length_range):
         return peptides_with_diff_length
 
 
-
 def split_peptides_with_diff_length_batch(input_sequence_text,
                                           peptide_length_range,
                                           batch_size=8192,
@@ -293,13 +292,37 @@ def split_parameters(input_data, split_inputs_dir=None):
     if basic_predictors:
         binding_method = basic_predictors[0]['mhc_binding_method']
         predictors = [p for p in predictors if p['type']!='binding' or p['method']!=binding_method]
+    has_non_allele_immunogenicity = False
     for allele in alleles:
         for predictor in predictors:
-            # for immunogenicity: skip invalid alleles if mask_choice == by_allele
             predictor_type = predictor.get('type','')
-            if predictor_type == 'immunogenicity' and predictor.get('mask_choice','') == 'by_allele' and not allele_validator.validate_alleles(allele, 'immunogenicity'):
-                # TODO: add warnings for this
-                print("Warning: allele {} is not available for immunogenicity.".format(allele))
+            # only split when mask_choice == 'by_allele'
+            if predictor_type == 'immunogenicity':
+                if predictor.get('mask_choice','') == 'by_allele':
+                    # for immunogenicity: skip invalid alleles if mask_choice == by_allele
+                    if not allele_validator.validate_alleles(allele, 'immunogenicity'):
+                        print("Warning: allele {} is not available for immunogenicity.".format(allele))
+                        continue
+                    methods = (predictor.get('method','immunogenicity'),)
+                    for method in methods:
+                        data_unit = input_data.copy()
+                        unit_predictor = predictor.copy()
+                        unit_predictor['method'] = method
+                        data_unit['alleles'] = allele
+                        data_unit['predictors'] = [unit_predictor]
+                        output_data.append(data_unit)
+                else:
+                    # only create one job for all alleles, do not join alleles
+                    if has_non_allele_immunogenicity:
+                        continue
+                    has_non_allele_immunogenicity = True
+                    methods = (predictor.get('method','immunogenicity'),)
+                    for method in methods:
+                        data_unit = input_data.copy()
+                        unit_predictor = predictor.copy()
+                        unit_predictor['method'] = method
+                        data_unit['predictors'] = [unit_predictor]
+                        output_data.append(data_unit)
                 continue
 
             method = predictor.get('method','')
@@ -486,4 +509,4 @@ if __name__ == '__main__':
     
     # summarize the list here
     #print(sp)
-    
+
